@@ -6,7 +6,25 @@ from django.http import HttpResponse, Http404
 from django_mediamosa.base import api
 
 
-class TinyMceAssetSelectionDialog(ListView):
+class TinyMcePrivateAssetSelectionDialog(ListView):
+    template_name = 'mediamosa_tinymce/tinymce_asset_dialog.html'
+    context_object_name = 'public_list'
+    paginate_by = 10
+
+    def get_queryset(self):
+        asset_list = api.asset_list(
+            mime_type='mp4',
+            mime_type_match='contains',
+            owner_id=self.request.user.username)
+        return asset_list
+
+    def get_context_data(self, **kwargs):
+        ctx = super(TinyMcePrivateAssetSelectionDialog, self).get_context_data(**kwargs)
+        ctx['my_tab'] = True
+        return ctx
+
+
+class TinyMcePublicAssetSelectionDialog(ListView):
     template_name = 'mediamosa_tinymce/tinymce_asset_dialog.html'
     context_object_name = 'public_list'
     paginate_by = 10
@@ -18,14 +36,6 @@ class TinyMceAssetSelectionDialog(ListView):
             is_public_list=True)
         return asset_list
 
-    def get_context_data(self, **kwargs):
-        context = super(TinyMceAssetSelectionDialog, self).get_context_data(**kwargs)
-        context['private_list'] = api.asset_list(
-            mime_type='mp4',
-            mime_type_match='contains',
-            owner_id=self.request.user.username)
-        return context
-
 
 class JSONTinyMceMediafileId(DetailView):
 
@@ -43,3 +53,5 @@ class JSONTinyMceMediafileId(DetailView):
         else:
             return HttpResponse(
                 json.dumps({'mediafile_id': self.object.id}))
+
+
